@@ -1,12 +1,15 @@
 """CSSPageRule implements DOM Level 2 CSS CSSPageRule."""
+
 __all__ = ['CSSPageRule']
 
+import xml.dom
 from itertools import chain
+
+import cssutils
+
+from . import cssrule
 from .cssstyledeclaration import CSSStyleDeclaration
 from .marginrule import MarginRule
-from . import cssrule
-import cssutils
-import xml.dom
 
 
 class CSSPageRule(cssrule.CSSRuleRules):
@@ -92,11 +95,7 @@ class CSSPageRule(cssrule.CSSRuleRules):
         self._readonly = readonly
 
     def __repr__(self):
-        return "cssutils.css.{}(selectorText={!r}, style={!r})".format(
-            self.__class__.__name__,
-            self.selectorText,
-            self.style.cssText,
-        )
+        return f"cssutils.css.{self.__class__.__name__}(selectorText={self.selectorText!r}, style={self.style.cssText!r})"
 
     def __str__(self):
         return (
