@@ -49,11 +49,13 @@ TODO:
       background: no-repeat left url()  #fff
       -> background: #fff url() no-repeat left
 """
+
 __all__ = ['CSSStyleDeclaration', 'Property']
 
+import cssutils
+
 from .cssproperties import CSS2Properties
 from .property import Property
-import cssutils
 
 
 class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
@@ -207,12 +209,7 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
         )
 
     def __str__(self):
-        return "<cssutils.css.{} object length={!r} (all: {!r}) at 0x{:x}>".format(
-            self.__class__.__name__,
-            self.length,
-            len(self.getProperties(all=True)),
-            id(self),
-        )
+        return f"<cssutils.css.{self.__class__.__name__} object length={self.length!r} (all: {len(self.getProperties(all=True))!r}) at 0x{id(self):x}>"
 
     def __nnames(self):
         """Return iterator for all different names in order as set
@@ -501,7 +498,7 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
         else:
             return None
 
-    def getPropertyValue(self, name, normalize=True):
+    def getPropertyValue(self, name, normalize=True, default=''):
         r"""
         :param name:
             of the CSS property, always lowercase (even if not normalized)
@@ -511,16 +508,18 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
 
             If ``False`` may return **NOT** the effective value but the
             effective for the unnormalized name.
+        :param default:
+            value to be returned if the property has not been set.
         :returns:
             the value of the effective property if it has been explicitly set
-            for this declaration block. Returns the empty string if the
+            for this declaration block. Returns `default` if the
             property has not been set.
         """
         p = self.getProperty(name, normalize)
         if p:
             return p.value
         else:
-            return ''
+            return default
 
     def getPropertyPriority(self, name, normalize=True):
         r"""
