@@ -5,15 +5,17 @@
 - CSSValueList implements DOM Level 2 CSS CSSValueList
 
 """
+
 __all__ = ['CSSValue', 'CSSPrimitiveValue', 'CSSValueList', 'RGBColor', 'CSSVariable']
 
-from cssutils.prodparser import Choice, PreDef, Prod, ProdParser, Sequence
-import cssutils
-import cssutils.helper
 import math
 import re
 import xml.dom
 
+import cssutils
+import cssutils.helper
+from cssutils.prodparser import Choice, PreDef, Prod, ProdParser, Sequence
+
 
 class CSSValue(cssutils.util._NewBase):
     """The CSSValue interface represents a simple or a complex value.
@@ -558,14 +560,7 @@ class CSSPrimitiveValue(CSSValue):
         super().__init__(cssText=cssText, parent=parent, readonly=readonly)
 
     def __str__(self):
-        return (
-            "<cssutils.css.{} object primitiveType={} cssText={!r} at 0x{:x}>".format(
-                self.__class__.__name__,
-                self.primitiveTypeString,
-                self.cssText,
-                id(self),
-            )
-        )
+        return f"<cssutils.css.{self.__class__.__name__} object primitiveType={self.primitiveTypeString} cssText={self.cssText!r} at 0x{id(self):x}>"
 
     _unitnames = [
         'CSS_UNKNOWN',
@@ -699,10 +694,10 @@ class CSSPrimitiveValue(CSSValue):
             val = float(val)
             if val == int(val):
                 val = int(val)
-        except ValueError:
+        except ValueError as err:
             raise xml.dom.InvalidAccessErr(
                 'CSSPrimitiveValue: No float value %r' % self._value[0]
-            )
+            ) from err
 
         return val, dim
 
@@ -734,14 +729,14 @@ class CSSPrimitiveValue(CSSValue):
             # convert if needed
             try:
                 val = self._converter[self.primitiveType, unitType](val)
-            except KeyError:
+            except KeyError as err:
                 raise xml.dom.InvalidAccessErr(
                     'CSSPrimitiveValue: Cannot coerce primitiveType %r to %r'
                     % (
                         self.primitiveTypeString,
                         self._getCSSPrimitiveTypeString(unitType),
                     )
-                )
+                ) from err
 
         if val == int(val):
             val = int(val)
@@ -778,24 +773,24 @@ class CSSPrimitiveValue(CSSValue):
             )
         try:
             val = float(floatValue)
-        except ValueError:
+        except ValueError as err:
             raise xml.dom.InvalidAccessErr(
                 'CSSPrimitiveValue: floatValue %r is not a float' % floatValue
-            )
+            ) from err
 
         oldval, dim = self._getNumDim()
         if self.primitiveType != unitType:
             # convert if possible
             try:
                 val = self._converter[unitType, self.primitiveType](val)
-            except KeyError:
+            except KeyError as err:
                 raise xml.dom.InvalidAccessErr(
                     'CSSPrimitiveValue: Cannot coerce primitiveType %r to %r'
                     % (
                         self.primitiveTypeString,
                         self._getCSSPrimitiveTypeString(unitType),
                     )
-                )
+                ) from err
 
         if val == int(val):
             val = int(val)
@@ -1135,12 +1130,7 @@ class RGBColor(CSSFunction):
         return f"cssutils.css.{self.__class__.__name__}({self.cssText!r})"
 
     def __str__(self):
-        return "<cssutils.css.{} object colorType={!r} cssText={!r} at 0x{:x}>".format(
-            self.__class__.__name__,
-            self.colorType,
-            self.cssText,
-            id(self),
-        )
+        return f"<cssutils.css.{self.__class__.__name__} object colorType={self.colorType!r} cssText={self.cssText!r} at 0x{id(self):x}>"
 
     def _setCssText(self, cssText):
         self._checkReadonly()
@@ -1316,12 +1306,7 @@ class CSSVariable(CSSValue):
         return f"cssutils.css.{self.__class__.__name__}({self.cssText!r})"
 
     def __str__(self):
-        return "<cssutils.css.{} object name={!r} value={!r} at 0x{:x}>".format(
-            self.__class__.__name__,
-            self.name,
-            self.value,
-            id(self),
-        )
+        return f"<cssutils.css.{self.__class__.__name__} object name={self.name!r} value={self.value!r} at 0x{id(self):x}>"
 
     def _setCssText(self, cssText):
         self._checkReadonly()
