@@ -3,6 +3,7 @@
 DOM Level 2 CSS CSSValue, CSSPrimitiveValue and CSSValueList are **no longer**
 supported and are replaced by these new classes.
 """
+
 __all__ = [
     'PropertyValue',
     'Value',
@@ -15,13 +16,14 @@ __all__ = [
     'MSValue',
 ]
 
-from cssutils.prodparser import Choice, PreDef, Prod, ProdParser, Sequence
-import cssutils
-from cssutils.helper import normalize, pushtoken
 import colorsys
 import re
 import urllib.parse
 
+import cssutils
+from cssutils.helper import normalize, pushtoken
+from cssutils.prodparser import Choice, PreDef, Prod, ProdParser, Sequence
+
 
 class PropertyValue(cssutils.util._NewBase):
     """
@@ -71,7 +73,7 @@ class PropertyValue(cssutils.util._NewBase):
         yield from self.__items()
 
     def __repr__(self):
-        return "cssutils.css.{}({!r})".format(self.__class__.__name__, self.cssText)
+        return f"cssutils.css.{self.__class__.__name__}({self.cssText!r})"
 
     def __str__(self):
         return "<cssutils.css.%s object length=%r cssText=%r at " "0x%x>" % (
@@ -254,18 +256,10 @@ class Value(cssutils.util._NewBase):
             self.cssText = cssText
 
     def __repr__(self):
-        return "cssutils.css.{}({!r})".format(self.__class__.__name__, self.cssText)
+        return f"cssutils.css.{self.__class__.__name__}({self.cssText!r})"
 
     def __str__(self):
-        return (
-            "<cssutils.css.{} object type={} value={!r} cssText={!r} at 0x{:x}>".format(
-                self.__class__.__name__,
-                self.type,
-                self.value,
-                self.cssText,
-                id(self),
-            )
-        )
+        return f"<cssutils.css.{self.__class__.__name__} object type={self.type} value={self.value!r} cssText={self.cssText!r} at 0x{id(self):x}>"
 
     def _setCssText(self, cssText):
         self._checkReadonly()
@@ -291,12 +285,14 @@ class Value(cssutils.util._NewBase):
         doc='String value of this value.',
     )
 
-    type = property(
-        lambda self: self._type,  # _setType,
-        doc="Type of this value, for now the production type "
-        "like e.g. `DIMENSION` or `STRING`. All types are "
-        "defined as constants in :class:`~cssutils.css.Value`.",
-    )
+    @property
+    def type(self):
+        """
+        Type of this value, for now the production type
+        like e.g. `DIMENSION` or `STRING`. All types are
+        defined as constants in :class:`~cssutils.css.Value`.
+        """
+        return self._type
 
     def _setValue(self, value):
         # TODO: check!
@@ -493,9 +489,10 @@ class ColorValue(Value):
         doc='Same as cssText but without comments.',
     )
 
-    type = property(
-        lambda self: Value.COLOR_VALUE, doc="Type is fixed to Value.COLOR_VALUE."
-    )
+    @property
+    def type(self):
+        """Type is fixed to Value.COLOR_VALUE."""
+        return Value.COLOR_VALUE
 
     def _getName(self):
         for n, v in list(self.COLORS.items()):
@@ -512,15 +509,21 @@ class ColorValue(Value):
     )
 
     red = property(lambda self: self._red, doc='red part as integer between 0 and 255')
-    green = property(
-        lambda self: self._green, doc='green part as integer between 0 and 255'
-    )
-    blue = property(
-        lambda self: self._blue, doc='blue part as integer between 0 and 255'
-    )
-    alpha = property(
-        lambda self: self._alpha, doc='alpha part as float between 0.0 and 1.0'
-    )
+
+    @property
+    def green(self):
+        """green part as integer between 0 and 255"""
+        return self._green
+
+    @property
+    def blue(self):
+        """blue part as integer between 0 and 255"""
+        return self._blue
+
+    @property
+    def alpha(self):
+        """alpha part as float between 0.0 and 1.0"""
+        return self._alpha
 
 
 class DimensionValue(Value):
@@ -600,14 +603,7 @@ class URIValue(Value):
     _uri = Value._value
 
     def __str__(self):
-        return "<cssutils.css.{} object type={} value={!r} uri={!r} cssText={!r} at 0x{:x}>".format(
-            self.__class__.__name__,
-            self.type,
-            self.value,
-            self.uri,
-            self.cssText,
-            id(self),
-        )
+        return f"<cssutils.css.{self.__class__.__name__} object type={self.type} value={self.value!r} uri={self.uri!r} cssText={self.cssText!r} at 0x{id(self):x}>"
 
     def _setCssText(self, cssText):
         self._checkReadonly()
@@ -784,9 +780,7 @@ class CSSCalc(CSSFunction):
     _functionName = 'CSSCalc'
 
     def __str__(self):
-        return "<cssutils.css.{} object at 0x{:x}>".format(
-            self.__class__.__name__, id(self)
-        )
+        return f"<cssutils.css.{self.__class__.__name__} object at 0x{id(self):x}>"
 
     def _setCssText(self, cssText):
         self._checkReadonly()
@@ -867,12 +861,7 @@ class CSSVariable(CSSFunction):
     _fallback = None
 
     def __str__(self):
-        return "<cssutils.css.{} object name={!r} value={!r} at 0x{:x}>".format(
-            self.__class__.__name__,
-            self.name,
-            self.value,
-            id(self),
-        )
+        return f"<cssutils.css.{self.__class__.__name__} object name={self.name!r} value={self.value!r} at 0x{id(self):x}>"
 
     def _setCssText(self, cssText):
         self._checkReadonly()
@@ -928,9 +917,10 @@ class CSSVariable(CSSFunction):
         ":class:`cssutils.css.CSSVariablesDeclaration`.",
     )
 
-    fallback = property(
-        lambda self: self._fallback, doc="The fallback Value of this variable"
-    )
+    @property
+    def fallback(self):
+        """The fallback Value of this variable"""
+        return self._fallback
 
     type = property(lambda self: Value.VARIABLE, doc="Type is fixed to Value.VARIABLE.")
 
