@@ -3,9 +3,7 @@
 import codecs
 import sys
 
-from . import helper
-from . import errorhandler
-from . import tokenize2
+from . import errorhandler, helper, tokenize2
 
 
 class ErrorHandler:
@@ -121,9 +119,6 @@ class EchoHandler(DocumentHandler):
         if 'utf-8' != encoding:
             self._out.append('@charset "%s";\n' % encoding)
 
-    #    def comment(self, text, line=None, col=None):
-    #        self._out.append(u'/*%s*/' % text)
-
     def importStyle(self, uri, media, name, line=None, col=None):
         "Receive notification of a import statement in the style sheet."
         # defaultNamespaceURI???
