@@ -10,8 +10,7 @@ def set(key, value):
     Clears the tokenizer cache which holds the compiled productions!
     """
     if key == 'DXImageTransform.Microsoft' and value is True:
-        from . import cssproductions
-        from . import tokenize2
+        from . import cssproductions, tokenize2
 
         tokenize2._TOKENIZER_CACHE.clear()
         cssproductions.PRODUCTIONS.insert(1, cssproductions._DXImageTransform)
