@@ -1,10 +1,13 @@
 """Tests for css.CSSStyleSheet"""
 
 import xml.dom
-from . import basetest
-import cssutils.css
+
 import pytest
 
+import cssutils.css
+
+from . import basetest
+
 
 class TestCSSStyleSheet(basetest.BaseTestCase):
     def setup_method(self):
@@ -12,9 +15,6 @@ class TestCSSStyleSheet(basetest.BaseTestCase):
         self.s = self.r  # used here
         self.rule = cssutils.css.CSSStyleRule()
 
-    def teardown_method(self):
-        cssutils.ser.prefs.useDefaults()
-
     def test_init(self):
         "CSSStyleSheet.__init__()"
         assert 'text/css' == self.s.type
@@ -84,7 +84,7 @@ class TestCSSStyleSheet(basetest.BaseTestCase):
         ).cssRules
         # new object
         assert rules != s.cssRules
-        for i, r in enumerate(s.cssRules):
+        for r in s.cssRules:
             assert r.parentStyleSheet == s
 
         # namespaces
@@ -155,7 +155,7 @@ test {
     }
 x|test {
     color: green
-    }"""
+    }""",
             #            ur'\1 { \2: \3 }': ur'''\x01 {
             #    \x02: \x03
             #    }''',
@@ -206,7 +206,7 @@ test {
     }
 x|test {
     color: green
-    }"""
+    }""",
             #            ur'\1 { \2: \3 }': ur'''\x01 {
             #    \x02: \x03
             #    }''',
