@@ -1,9 +1,6 @@
 """Testcases for cssutils.css.CSSCharsetRule"""
 
-
-from . import basetest
 import codecs
-import cssutils
 import os
 import sys
 import tempfile
@@ -11,6 +8,10 @@ from unittest import mock
 
 import pytest
 
+import cssutils
+
+from . import basetest
+
 
 @pytest.fixture
 def serializer(monkeypatch):
@@ -18,12 +19,6 @@ def serializer(monkeypatch):
 
 
 class TestCSSutils(basetest.BaseTestCase):
-    def setup_method(self):
-        cssutils.ser.prefs.useDefaults()
-
-    def teardown_method(self):
-        cssutils.ser.prefs.useDefaults()
-
     exp = '''@import "import/import2.css";
 .import {
     /* ./import.css */
@@ -77,7 +72,7 @@ class TestCSSutils(basetest.BaseTestCase):
         }
         self.do_equal_p(tests)
 
-    def test_parseFile(self):
+    def test_parseFile(self, monkeypatch):
         "cssutils.parseFile()"
         # name if used with open, href used for @import resolving
         name = basetest.get_sheet_filename('import.css')
@@ -118,7 +113,7 @@ class TestCSSutils(basetest.BaseTestCase):
 
         # name is used for open and setting of href automatically
         # test needs to be relative to this test file!
-        os.chdir(os.path.dirname(__file__))
+        monkeypatch.chdir(os.path.dirname(__file__))
         name = basetest.get_sheet_filename('import.css')
 
         s = cssutils.parseFile(name, media='screen', title='from file')
@@ -385,7 +380,7 @@ background-image: url(prefix/1.png), url(prefix/2.png)'''
             assert b'\xc3\xa4{color:red}\xc3\xa4{color:green}' == c.cssText
 
             c.encoding = 'ascii'
-            assert br'@charset "ascii";\E4 {color:red}\E4 {color:green}' == c.cssText
+            assert rb'@charset "ascii";\E4 {color:red}\E4 {color:green}' == c.cssText
 
         # b cannot be found
         m = mock.Mock()
@@ -481,5 +476,3 @@ a {
     z: url(b/subimg/subimg.gif)
     }'''
         assert expected == r.cssText
-
-        cssutils.ser.prefs.useDefaults()
