@@ -1,6 +1,7 @@
 """Testcases for cssutils.css.property._Property."""
 
 import copy
+
 import cssutils
 from cssutils.css.property import Property
 
@@ -8,7 +9,7 @@ debug = False
 
 
 class TestProperties:
-    def setup(self):
+    def setup_method(self):
         "init test values"
         V = {
             '0': ('0', '-0'),  # , '+0'),
