@@ -1,12 +1,12 @@
-"""New CSS Tokenizer (a generator)
-"""
+"""New CSS Tokenizer (a generator)"""
+
 __all__ = ['Tokenizer', 'CSSProductions']
 
 import itertools
 import re
 import sys
 
-from .cssproductions import CSSProductions, MACROS, PRODUCTIONS
+from .cssproductions import MACROS, PRODUCTIONS, CSSProductions
 from .helper import normalize
 
 _TOKENIZER_CACHE = {}
